pub struct User {Show 14 fields
pub id: Uuid,
pub active_character_id: Uuid,
pub tg_id: Option<i64>,
pub firebase_id: Option<String>,
pub photo_url: Option<String>,
pub is_premium: Option<bool>,
pub is_deleted: bool,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub username: String,
pub username_discriminator: Option<i64>,
pub last_username_change_at: Option<DateTime<Utc>>,
pub language_code: String,
pub allows_write_to_pm: Option<bool>,
}Fields
id: Uuidactive_character_id: Uuidtg_id: Option<i64>firebase_id: Option<String>photo_url: Option<String>is_deleted: boolfirst_name: Option<String>last_name: Option<String>username: Stringusername_discriminator: Option<i64>last_username_change_at: Option<DateTime<Utc>>language_code: Stringallows_write_to_pm: Option<bool>Trait Implementations
Sourceimpl CustomType for User
impl CustomType for User
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for User
impl<'de> Deserialize<'de> for User
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for User
impl JsonSchema for User
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for User
impl Tsify for User
const DECL: &'static str = "export interface User {\n id: Uuid;\n active_character_id: Uuid;\n tg_id: number | null;\n firebase_id: string | null;\n photo_url: string | null;\n is_premium: boolean | null;\n is_deleted: boolean;\n first_name: string | null;\n last_name: string | null;\n username: string;\n username_discriminator: number | null;\n last_username_change_at: DateTime<Utc> | null;\n language_code: string;\n allows_write_to_pm: boolean | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for User
impl StructuralPartialEq for User